summaryrefslogtreecommitdiff
path: root/src/testing/testing_api_cmd_set_wire_fee.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/testing/testing_api_cmd_set_wire_fee.c')
-rw-r--r--src/testing/testing_api_cmd_set_wire_fee.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/testing/testing_api_cmd_set_wire_fee.c b/src/testing/testing_api_cmd_set_wire_fee.c
index ed3448ac5..f0f76a874 100644
--- a/src/testing/testing_api_cmd_set_wire_fee.c
+++ b/src/testing/testing_api_cmd_set_wire_fee.c
@@ -77,13 +77,14 @@ struct WireFeeState
* if the response code is acceptable.
*
* @param cls closure.
* @param hr HTTP response details
*/
static void
wire_add_cb (void *cls,
- const struct TALER_EXCHANGE_HttpResponse *hr)
+ const struct TALER_EXCHANGE_ManagementSetWireFeeResponse *sfr)
{
struct WireFeeState *ds = cls;
+ const struct TALER_EXCHANGE_HttpResponse *hr = &sfr->hr;
ds->dh = NULL;
if (ds->expected_response_code != hr->http_status)
@@ -77,13 +77,14 @@ struct WireFeeState
*
* @param cls closure.
- * @param hr HTTP response details
+ * @param sfr response details
*/
static void